@@ -622,7 +622,7 @@ class TestPollingAgent(BaseAgent):
         pollster = list(polling_task.pollster_matches['test_polling'])[0]
         polling_task.poll_and_notify()
         LOG.debug.assert_called_with(
-            'Skip pollster %(name)s, no %(p_context)sresources found this '
+            'Skip pollster %(name)s, no %(p_context)s resources found this '
             'cycle', {'name': pollster.name, 'p_context': ''})
 
     @mock.patch('ceilometer.polling.manager.LOG')
@@ -637,7 +637,7 @@ class TestPollingAgent(BaseAgent):
         polling_task = list(self.mgr.setup_polling_tasks().values())[0]
         polling_task.poll_and_notify()
         LOG.debug.assert_called_with(
-            'Skip pollster %(name)s, no %(p_context)sresources found this '
+            'Skip pollster %(name)s, no %(p_context)s resources found this '
             'cycle', {'name': 'test', 'p_context': 'new '})
 
     @mock.patch('oslo_utils.timeutils.utcnow')
@@ -677,7 +677,6 @@ class TestPollingAgent(BaseAgent):
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
-                'transformers': [],
                 'publishers': ["test"]}]
         }
         self.setup_polling(poll_cfg)
@@ -720,7 +719,6 @@ class TestPollingAgent(BaseAgent):
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
-                'transformers': [],
                 'publishers': ["test"]}]
         }
         self.setup_polling(poll_cfg)
@@ -742,7 +740,6 @@ class TestPollingAgent(BaseAgent):
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
-                'transformers': [],
                 'publishers': ["test"]}]
         }
         self.setup_polling(poll_cfg)
@@ -771,7 +768,6 @@ class TestPollingAgent(BaseAgent):
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
-                'transformers': [],
                 'publishers': ["test"]}]
         }
         self.setup_polling(poll_cfg)
@@ -791,10 +787,6 @@ class TestPollingAgent(BaseAgent):
                  res_list="[<NovaLikeServer: unknown-name>]",
                  source=source_name))
 
-    def test_batching_polled_samples_false_deprecated(self):
-        self.CONF.set_override('batch_polled_samples', False)
-        self._batching_samples(4, 4)
-
     def test_batching_polled_samples_disable_batch(self):
         self.CONF.set_override('batch_size', 0, group='polling')
         self._batching_samples(4, 4)
@@ -816,7 +808,6 @@ class TestPollingAgent(BaseAgent):
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
-                'transformers': [],
                 'publishers': ["test"]}]
         }
         self.setup_polling(poll_cfg)
